# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: simulation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import messages_pb2 as messages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='simulation.proto',
  package='robotc',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10simulation.proto\x12\x06robotc\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0emessages.proto\"\x15\n\x06SimRes\x12\x0b\n\x03ret\x18\x01 \x01(\x05\"&\n\tButtonReq\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\x05\"(\n\x0b\x44ialgageReq\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\"\x1b\n\nRobotSpeed\x12\r\n\x05\x63ycle\x18\x01 \x01(\r2\xc3\x03\n\x14SimulationController\x12\'\n\x06SetPos\x12\r.robotc.JPose\x1a\x0e.robotc.SimRes\x12/\n\x05\x45Stop\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.SimRes\x12\x36\n\x0c\x45StopRelease\x12\x16.google.protobuf.Empty\x1a\x0e.robotc.SimRes\x12+\n\x06\x42utton\x12\x11.robotc.ButtonReq\x1a\x0e.robotc.SimRes\x12\x32\n\x0bSetDialgage\x12\x13.robotc.DialgageReq\x1a\x0e.robotc.SimRes\x12)\n\nSetRobotAI\x12\x0b.robotc.AIO\x1a\x0e.robotc.SimRes\x12)\n\nSetRobotDI\x12\x0b.robotc.DIO\x1a\x0e.robotc.SimRes\x12*\n\x0bSetFlangeDI\x12\x0b.robotc.DIO\x1a\x0e.robotc.SimRes\x12\x36\n\x10\x43hangeRobotSpeed\x12\x12.robotc.RobotSpeed\x1a\x0e.robotc.SimResb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,messages__pb2.DESCRIPTOR,])




_SIMRES = _descriptor.Descriptor(
  name='SimRes',
  full_name='robotc.SimRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret', full_name='robotc.SimRes.ret', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=94,
)


_BUTTONREQ = _descriptor.Descriptor(
  name='ButtonReq',
  full_name='robotc.ButtonReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.ButtonReq.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='robotc.ButtonReq.state', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=134,
)


_DIALGAGEREQ = _descriptor.Descriptor(
  name='DialgageReq',
  full_name='robotc.DialgageReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.DialgageReq.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.DialgageReq.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=176,
)


_ROBOTSPEED = _descriptor.Descriptor(
  name='RobotSpeed',
  full_name='robotc.RobotSpeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cycle', full_name='robotc.RobotSpeed.cycle', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=205,
)

DESCRIPTOR.message_types_by_name['SimRes'] = _SIMRES
DESCRIPTOR.message_types_by_name['ButtonReq'] = _BUTTONREQ
DESCRIPTOR.message_types_by_name['DialgageReq'] = _DIALGAGEREQ
DESCRIPTOR.message_types_by_name['RobotSpeed'] = _ROBOTSPEED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimRes = _reflection.GeneratedProtocolMessageType('SimRes', (_message.Message,), {
  'DESCRIPTOR' : _SIMRES,
  '__module__' : 'simulation_pb2'
  # @@protoc_insertion_point(class_scope:robotc.SimRes)
  })
_sym_db.RegisterMessage(SimRes)

ButtonReq = _reflection.GeneratedProtocolMessageType('ButtonReq', (_message.Message,), {
  'DESCRIPTOR' : _BUTTONREQ,
  '__module__' : 'simulation_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ButtonReq)
  })
_sym_db.RegisterMessage(ButtonReq)

DialgageReq = _reflection.GeneratedProtocolMessageType('DialgageReq', (_message.Message,), {
  'DESCRIPTOR' : _DIALGAGEREQ,
  '__module__' : 'simulation_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DialgageReq)
  })
_sym_db.RegisterMessage(DialgageReq)

RobotSpeed = _reflection.GeneratedProtocolMessageType('RobotSpeed', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTSPEED,
  '__module__' : 'simulation_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RobotSpeed)
  })
_sym_db.RegisterMessage(RobotSpeed)



_SIMULATIONCONTROLLER = _descriptor.ServiceDescriptor(
  name='SimulationController',
  full_name='robotc.SimulationController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=208,
  serialized_end=659,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetPos',
    full_name='robotc.SimulationController.SetPos',
    index=0,
    containing_service=None,
    input_type=messages__pb2._JPOSE,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EStop',
    full_name='robotc.SimulationController.EStop',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EStopRelease',
    full_name='robotc.SimulationController.EStopRelease',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Button',
    full_name='robotc.SimulationController.Button',
    index=3,
    containing_service=None,
    input_type=_BUTTONREQ,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDialgage',
    full_name='robotc.SimulationController.SetDialgage',
    index=4,
    containing_service=None,
    input_type=_DIALGAGEREQ,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRobotAI',
    full_name='robotc.SimulationController.SetRobotAI',
    index=5,
    containing_service=None,
    input_type=messages__pb2._AIO,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetRobotDI',
    full_name='robotc.SimulationController.SetRobotDI',
    index=6,
    containing_service=None,
    input_type=messages__pb2._DIO,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetFlangeDI',
    full_name='robotc.SimulationController.SetFlangeDI',
    index=7,
    containing_service=None,
    input_type=messages__pb2._DIO,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangeRobotSpeed',
    full_name='robotc.SimulationController.ChangeRobotSpeed',
    index=8,
    containing_service=None,
    input_type=_ROBOTSPEED,
    output_type=_SIMRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SIMULATIONCONTROLLER)

DESCRIPTOR.services_by_name['SimulationController'] = _SIMULATIONCONTROLLER

# @@protoc_insertion_point(module_scope)
